
# Type: molecular activity_enabled by




URI: [biolink:molecular_activity_enabled_by](https://w3id.org/biolink/vocab/molecular_activity_enabled_by)


## Domain and Range

[MolecularActivity](MolecularActivity.md) ->  <sub>0..*</sub> [MacromolecularMachine](MacromolecularMachine.md)

## Parents

 *  is_a: [enabled by](enabled_by.md)

## Children


## Used by

 * [MolecularActivity](MolecularActivity.md)
